@@ -27,7 +27,7 @@
    Mac OS X, we prefer those defines to decide the endianness.
    Elsewhere use the platform check result.  */
 #if !defined(__APPLE__)
-/* #undef GDCM_WORDS_BIGENDIAN */
+ #define GDCM_WORDS_BIGENDIAN
 #elif defined(__BIG_ENDIAN__)
 # define GDCM_WORDS_BIGENDIAN
 #endif
@@ -40,9 +40,9 @@
 
 /* Usefull in particular for loadshared where the full path
  * to the lib is needed */
-#define GDCM_SOURCE_DIR "/pobj/gdcm-3.0.5/gdcm-3.0.5"
-#define GDCM_EXECUTABLE_OUTPUT_PATH "/pobj/gdcm-3.0.5/build-i386/bin"
-#define GDCM_LIBRARY_OUTPUT_PATH    "/pobj/gdcm-3.0.5/build-i386/bin"
+#define GDCM_SOURCE_DIR "/usr/obj/ports/gdcm-3.0.7/gdcm-3.0.7"
+#define GDCM_EXECUTABLE_OUTPUT_PATH "/usr/obj/ports/gdcm-3.0.7/build-sparc64/bin"
+#define GDCM_LIBRARY_OUTPUT_PATH    "/usr/obj/ports/gdcm-3.0.7/build-sparc64/bin"
 
 /* #undef GDCM_BUILD_TESTING */
 
@@ -145,8 +145,8 @@
 /* Version number.  */
 #define GDCM_MAJOR_VERSION 3
 #define GDCM_MINOR_VERSION 0
-#define GDCM_BUILD_VERSION 5
-#define GDCM_VERSION "3.0.5"
+#define GDCM_BUILD_VERSION 7
+#define GDCM_VERSION "3.0.7"
 #define GDCM_API_VERSION "3.0"
 
 /*
